@@ -1,8 +1,9 @@
 package Config::MVP::Error;
-BEGIN {
-  $Config::MVP::Error::VERSION = '2.200001';
+{
+  $Config::MVP::Error::VERSION = '2.200003';
 }
 use Moose;
+# ABSTRACT: common exceptions class
 
 has message => (
   is  => 'ro',
@@ -35,15 +36,16 @@ __PACKAGE__->meta->make_immutable(inline_constructor => 0);
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
 
-Config::MVP::Error
+Config::MVP::Error - common exceptions class
 
 =head1 VERSION
 
-version 2.200001
+version 2.200003
 
 =head1 AUTHOR
 
@@ -51,10 +53,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
